var Clock = new Object();

Clock.currentTime = new Date;
Clock.timerId = -1;

Clock.start = function(clockEl, uptimeEl)
{
    Clock.clockEl = clockEl;
    Clock.uptimeEl = uptimeEl;
    Clock.refresh_from_server();
}

Clock.refresh_from_server = function()
{
    var query = new ServerQuery(Clock.refresh_callback, Clock.error_callback);
    query.sendRequest("/get/time");
}

Clock.refresh_callback = function()
{
    var parser = new JSONParser(this.request.responseText);
    var json_object;
    try
    {
        json_object = parser.parse();

        Clock.cache_time(json_object);

        if (Clock.timerId == -1)
        {
            Clock.timerId = setInterval('Clock.refresh_local()', 1000);
        }

        setTimeout('Clock.refresh_from_server()', 60000);
    }
    catch (e)
    {
        return;
    }
}

Clock.error_callback = function()
{
    clearInterval(Clock.timerId);
    Clock.timerId = -1;

    if (Clock.clockEl != undefined)
    {
        Clock.clockEl.nodeValue = "";
    }
    if (Clock.uptimeEl != undefined)
    {
        Clock.uptimeEl.nodeValue = "";
    }

    setTimeout('Clock.refresh_from_server()', 10000);
}

Clock.cache_time = function(current)
{
    Clock.currentTime.setFullYear(current.time.year, current.time.month, current.time.day);
    Clock.currentTime.setHours(current.time.hour);
    Clock.currentTime.setMinutes(current.time.minute);
    Clock.currentTime.setSeconds(current.time.second);

    Clock.uptime = current.uptime;

    Clock.update();
}

Clock.refresh_local = function()
{
    Clock.currentTime.setSeconds(Clock.currentTime.getSeconds() + 1);
    Clock.uptime = Clock.uptime + 1;
    Clock.update();
}

Clock.secondsToNiceStr = function(seconds)
{
    var days = Math.floor(seconds / 86400);
    seconds -= (days * 86400);

    var hours = Math.floor(seconds / 3600);
    seconds -= (hours * 3600);

    var minutes = Math.floor(seconds / 60);
    seconds -= (minutes * 60);

    return printf("%dd %02dh %02dm %02ds", days, hours, minutes, seconds);
}

Clock.update = function()
{
    if (Clock.clockEl != undefined)
    {
        Clock.clockEl.innerHTML = Clock.currentTime.toLocaleString();
    }
    if (Clock.uptimeEl != undefined)
    {
        Clock.uptimeEl.innerHTML = Clock.secondsToNiceStr(Clock.uptime);
    }
}
